from .base_model import *


class AtfFileType(BaseModel):
    """
    Тип прикрепленного документа
    """

    id = models.AutoField(db_column="FileTypeID", primary_key=True)
    uuid = models.CharField(db_column="Guid", max_length=36, unique=True, default=uuid4)

    code = models.CharField(db_column="Code", max_length=100, default="")
    name = models.TextField(db_column="Name")
    description = models.TextField(db_column="Description", default="")
    date_begin = models.DateTimeField(db_column="DateBegin", default=timezone.now)
    date_end = models.DateTimeField(db_column="DateEnd", default=timezone.datetime(2222, 1, 1))

    flags = models.IntegerField(db_column="Flags", default=0)

    class Meta:
        managed = False
        db_table = "atf_FileType"



from .base_model import *


class KlaHouse(BaseModel):
    id = models.AutoField(db_column="HouseID", primary_key=True)
    code = models.CharField(db_column="CODE", max_length=17)
    number = models.CharField(db_column="Number", max_length=10)
    building = models.CharField(db_column="Building", max_length=10)
    construction = models.CharField(db_column="Construction", max_length=10)
    post_index = models.CharField(db_column="PostIndex", max_length=6)
    street = models.ForeignKey("KlaStreet", models.DO_NOTHING, db_column="rf_StreetID")

    flags = models.IntegerField(db_column="Flags")

    class Meta:
        managed = False
        db_table = "kla_House"



from .base_model import *


class OmsOkato(BaseModel):
    """
    Коды территорий по ОКАТО
    """

    id = models.AutoField(db_column="OKATOID", primary_key=True)
    c_okato = models.CharField(db_column="C_OKATO", max_length=15)
    msg_text = models.CharField(db_column="MSG_TEXT", max_length=250)
    o_name = models.CharField(db_column="O_NAME", max_length=250)
    c_pfr = models.DecimalField(db_column="C_PFR", max_digits=5, decimal_places=0)
    fok_name = models.CharField(db_column="FOK_NAME", max_length=60)
    pfr_code = models.IntegerField(db_column="PFRcode")
    date_b = models.DateTimeField(db_column="Date_B")
    date_e = models.DateTimeField(db_column="Date_E")

    class Meta:
        managed = False
        db_table = "oms_OKATO"



from .base_model import *


class HltPolisMkab(BaseModel):
    """
    Полиса пациентов
    """

    id = models.AutoField(db_column="PolisMKABID", primary_key=True)
    date_pol_begin = models.DateTimeField(db_column="DatePolBegin")
    date_pol_end = models.DateTimeField(db_column="DatePolEnd")
    guid = models.CharField(db_column="GUID", max_length=36)
    is_active = models.BooleanField(db_column="isActive")
    s_pol = models.CharField(db_column="S_POL", max_length=50)
    n_pol = models.CharField(db_column="N_POL", max_length=50)
    profit_type = models.ForeignKey("OmsKlProfitType", db_column="rf_kl_ProfitTypeID", **FK_DEFAULT)
    tip_oms = models.ForeignKey("OmsKlTipOms", db_column="rf_kl_TipOMSID", **FK_DEFAULT)
    mkab = models.ForeignKey("HltMkab", db_column="rf_MKABID", **FK_DEFAULT)
    smo = models.ForeignKey("OmsLpu", db_column="rf_SMOID", **FK_DEFAULT)
    dogovor_id = models.IntegerField(db_column="rf_DOGOVORID")
    flags = models.IntegerField(db_column="Flags")

    class Meta:
        managed = False
        db_table = "hlt_polismkab"



from .base_model import *


class OmsSmo(BaseModel):
    """
    Страховые медицинские организации (СМО)
    """

    id = models.AutoField(db_column="SMOID", primary_key=True)
    okato = models.ForeignKey("OmsOkato", models.DO_NOTHING, db_column="rf_OKATOID")
    q_ogrn = models.CharField(db_column="Q_OGRN", max_length=15)
    q_name = models.CharField(db_column="Q_NAME", max_length=150)
    fam_ruk = models.CharField(db_column="FAM_RUK", max_length=40)
    im_ruk = models.CharField(db_column="IM_RUK", max_length=40)
    ot_ruk = models.CharField(db_column="OT_RUK", max_length=40)
    fam_bux = models.CharField(db_column="FAM_BUX", max_length=40)
    im_bux = models.CharField(db_column="IM_BUX", max_length=40)
    ot_bux = models.CharField(db_column="OT_BUX", max_length=40)
    tel = models.CharField(db_column="TEL", max_length=40)
    fax = models.CharField(db_column="FAX", max_length=40)
    e_mail = models.CharField(db_column="E_MAIL", max_length=50)
    date_b = models.DateTimeField(db_column="DATE_B")
    date_e = models.DateTimeField(db_column="DATE_E")
    address = models.CharField(db_column="ADRES", max_length=200)
    post_idp = models.DecimalField(db_column="POST_IDP", max_digits=6, decimal_places=0)
    okpo = models.CharField(db_column="OKPO", max_length=8)
    cod = models.CharField(db_column="COD", max_length=6)
    organisation = models.ForeignKey("OmsOrganisation", models.DO_NOTHING, db_column="rf_OrganisationID")
    other_ter_flag = models.BooleanField(db_column="OtherTerFlag")
    code_cmo = models.IntegerField(db_column="Code_CMO")
    smo_cod = models.CharField(max_length=7, db_column="smocod")
    profit_type = models.ForeignKey("OmsKlProfitType", models.DO_NOTHING, db_column="rf_kl_ProfitTypeID")
    address_fact = models.CharField(db_column="ADRESF", max_length=200)
    inn = models.CharField(db_column="INN", max_length=17)
    kpp = models.DecimalField(db_column="KPP", max_digits=9, decimal_places=0)
    post_idpf = models.DecimalField(db_column="POST_IDPF", max_digits=6, decimal_places=0)
    q_namef = models.CharField(db_column="Q_NAMEF", max_length=255)
    rem = models.CharField(db_column="Rem", max_length=255)

    flags = models.IntegerField(db_column="FLAGS")

    class Meta:
        managed = False
        db_table = "oms_SMO"



from .base_model import *


class OmsDepartment(BaseModel):
    id = models.AutoField(db_column="DepartmentID", primary_key=True)
    uuid = models.CharField(db_column="GUIDDepartment", max_length=36, unique=True)

    code = models.CharField(db_column="DepartmentCODE", max_length=50)
    name = models.CharField(db_column="DepartmentNAME", max_length=255)
    type = models.ForeignKey("OmsKlDepartmentType", db_column="rf_kl_DepartmentTypeID", **FK_DEFAULT)
    lpu = models.ForeignKey("OmsLpu", models.DO_NOTHING, db_column="rf_LPUID")
    zav_pcod = models.CharField(db_column="ZAVPCOD", max_length=10)
    zav_fio = models.CharField(db_column="ZAVFIO", max_length=70)
    profile = models.ForeignKey("OmsKlDepartmentProfile", db_column="rf_kl_DepartmentProfileID", **FK_DEFAULT)
    code_department = models.IntegerField(db_column="Code_Department")
    n_otd = models.CharField(db_column="N_OTD", max_length=5)
    rem = models.CharField(db_column="Rem", max_length=255)
    age_group = models.ForeignKey("OmsKlAgeGroup", db_column="rf_kl_AgeGroupID", **FK_DEFAULT)
    date_b = models.DateTimeField(db_column="Date_B")
    date_e = models.DateTimeField(db_column="Date_E")
    code_kladr = models.CharField(db_column="CodeKLADR", max_length=10)
    fax = models.CharField(db_column="FAX", max_length=50)
    address = models.ForeignKey("KlaAddress", db_column="rf_AddressID", **FK_DEFAULT)
    tel = models.CharField(db_column="Tel", max_length=50)
    med_care_type = models.ForeignKey("OmsKlMedCareType", db_column="rf_kl_MedCareTypeID", **FK_DEFAULT)

    class Meta:
        managed = False
        db_table = "oms_Department"



from .base_model import *


class HltUchastok(BaseModel):
    id = models.AutoField(db_column="UchastokID", primary_key=True)
    uuid = models.CharField(db_column="UGUID", max_length=36, unique=True)

    caption = models.CharField(db_column="UchastoCaption", max_length=500)
    code = models.CharField(db_column="CODE", max_length=6)
    doctor = models.ForeignKey("HltLpuDoctor", db_column="rf_LPUDoctorID", **FK_DEFAULT)
    doc_prvd = models.ForeignKey("HltDocPrvd", db_column="rf_DocPRVDID", **FK_DEFAULT)
    type_uid = models.IntegerField(db_column="rf_kl_TypeUID")
    lpu = models.ForeignKey("OmsLpu", db_column="rf_LPUID", **FK_DEFAULT)
    is_closed = models.IntegerField(db_column="isClosed")
    code_smo = models.CharField(db_column="CodeSMO", max_length=6)
    date_begin = models.DateTimeField(db_column="DateBegin")
    date_end = models.DateTimeField(db_column="DateEnd")
    flags = models.IntegerField(db_column="Flags")

    class Meta:
        managed = False
        db_table = "hlt_Uchastok"



from .base_model import *


class OmsPrvs(models.Model):
    id = models.AutoField(db_column="PRVSID", primary_key=True)
    c_prvs = models.CharField(db_column="C_PRVS", max_length=100)
    prvs_name = models.CharField(db_column="PRVS_NAME", max_length=100)
    msg_text = models.CharField(db_column="MSG_TEXT", max_length=100)
    i_prvs = models.IntegerField(db_column="I_PRVS")
    date_beg = models.DateTimeField(db_column="Date_Beg")
    date_end = models.DateTimeField(db_column="Date_End")
    main_prvs = models.ForeignKey("self", db_column="rf_MainPRVSID", **FK_DEFAULT)
    prvs = models.ForeignKey("self", db_column="rf_PRVSID", **FK_DEFAULT)
    id_post_mz = models.CharField(db_column="IDPost_MZ", max_length=50)
    post_name = models.CharField(db_column="PostName", max_length=150)
    profit_type = models.ForeignKey("OmsKlProfitType", db_column="rf_kl_ProfitTypeID", **FK_DEFAULT)
    prvd = models.ForeignKey("OmsPrvd", db_column="rf_PRVDID", **FK_DEFAULT)

    class Meta:
        managed = False
        db_table = "oms_PRVS"



from .base_model import *


class HltVisitHistory(BaseModel):
    """
    Обращение
    """

    id = models.AutoField(db_column="VisitHistoryID", primary_key=True)
    uuid = models.CharField(db_column="GUID", max_length=36, unique=True, default=uuid4)
    date = models.DateTimeField(db_column="Date")
    is_complete = models.BooleanField(db_column="IsComplete")
    doctor_visit_table = models.ForeignKey("HltDoctorVisitTable", db_column="rf_DoctorVisitTableID", **FK_DEFAULT)
    lpu_doctor = models.IntegerField(db_column="rf_LPUDoctorID")
    mkab = models.ForeignKey("HltMkab", models.DO_NOTHING, db_column="rf_MKABID", related_name="visits")
    tap = models.ForeignKey("HltTap", models.DO_NOTHING, db_column="rf_TAPID", related_name="visits")
    begin_time = models.DateTimeField(db_column="BeginTime")
    fact_begin_time = models.DateTimeField(db_column="FactBeginTime")
    fact_end_time = models.DateTimeField(db_column="FactEndTime")
    doc_prvd = models.ForeignKey("HltDocPrvd", db_column="rf_DocPRVDID", **FK_DEFAULT)
    conclusion = models.TextField(db_column="Conclusion")
    date_conclusion = models.DateTimeField(db_column="DateConclusion")

    flags = models.IntegerField(db_column="Flags")

    class Meta:
        managed = False
        db_table = "hlt_VisitHistory"



from .base_model import *


class OmsTypedoc(BaseModel):
    """
    П: Типы документов, удостоверяющих личность
    """

    id = models.AutoField(db_column="TYPEDOCID", primary_key=True)
    c_doc = models.BigIntegerField(db_column="C_DOC")
    name_pfr = models.CharField(db_column="NAME_PFR", max_length=20)
    name = models.CharField(db_column="NAME", max_length=100)
    date_b = models.DateTimeField(db_column="Date_B")
    date_e = models.DateTimeField(db_column="Date_E")
    doc_num = models.CharField(db_column="DocNum", max_length=20)
    doc_ser = models.CharField(db_column="DocSer", max_length=10)
    code_egisz = models.CharField(db_column="CodeEgisz", max_length=150)

    class Meta:
        managed = False
        db_table = "oms_TYPEDOC"



import datetime

from .base_model import *


class HltSmTap(BaseModel):
    id = models.AutoField(db_column="SMTAPID", primary_key=True)
    tap = models.ForeignKey("HltTap", db_column="rf_TAPID", **FK_DEFAULT)
    reg_s = models.SmallIntegerField(db_column="REG_S", default=0)
    uuid = models.CharField(db_column="SMTAPGuid", max_length=36, unique=True, default=uuid4)
    is_fake = models.BooleanField(db_column="IsFake", default=0)
    lpu_doctor = models.ForeignKey("HltLpuDoctor", db_column="rf_LPUDoctorID", **FK_DEFAULT)
    count = models.DecimalField(db_column="Count", max_digits=9, decimal_places=2, default=0)
    date_p = models.DateTimeField(db_column="DATE_P", default=timezone.now)
    doctor_visit_table = models.ForeignKey("HltDoctorVisitTable", db_column="rf_DoctorVisitTableID", **FK_DEFAULT)
    flags = models.IntegerField(db_column="FLAGS", default=0)
    lpu = models.ForeignKey("OmsLpu", db_column="rf_LPUID", **FK_DEFAULT)
    mkb = models.ForeignKey("OmsMkb", db_column="rf_MKBID", **FK_DEFAULT)
    description = models.CharField(db_column="Description", max_length=1000, default="")
    service_medical = models.ForeignKey("OmsServiceMedical", db_column="rf_omsServiceMedicalID", **FK_DEFAULT)
    tariff_id = models.IntegerField(db_column="rf_TariffID", default=0)
    department = models.ForeignKey("OmsDepartment", db_column="rf_DepartmentID", **FK_DEFAULT)
    create_user_name = models.CharField(db_column="CreateUserName", max_length=255, default="не определено")
    edit_user_name = models.CharField(db_column="EditUserName", max_length=255, default="не определено")
    flag_bill = models.BooleanField(db_column="FlagBill", default=0)
    flag_complete = models.BooleanField(db_column="FlagComplete", default=0)
    flag_pay = models.BooleanField(db_column="FlagPay", default=0)
    flag_statist = models.BooleanField(db_column="FlagStatist", default=0)
    create_user = models.ForeignKey("XUser", db_column="rf_CreateUserID", **FK_DEFAULT)
    edit_user = models.ForeignKey("XUser", db_column="rf_EditUserID", **FK_DEFAULT)
    invoice_id = models.IntegerField(db_column="rf_InvoiceID", default=0)
    doc_prvd = models.ForeignKey("HltDocPrvd", db_column="rf_DocPRVDID", **FK_DEFAULT)
    sum_opl = models.DecimalField(db_column="Sum_Opl", max_digits=18, decimal_places=2, default=0)
    sum_v = models.DecimalField(db_column="Sum_V", max_digits=18, decimal_places=2, default=0)
    date_e = models.DateTimeField(db_column="DATE_E", default=timezone.now)
    visit_place = models.ForeignKey("OmsKlVisitPlace", db_column="rf_kl_VisitPlaceID", **FK_DEFAULT)
    lpu_doctor_sid = models.IntegerField(db_column="rf_LPUDoctor_SID", default=0)
    bill_service_id = models.IntegerField(db_column="rf_BillServiceID", default=0)
    root_sm_tap = models.ForeignKey("HltSmTap", db_column="rf_RootSMTAPID", **FK_DEFAULT)
    operation_id = models.IntegerField(db_column="rf_OperationID", default=0)
    teeth_id = models.IntegerField(db_column="rf_kl_TeethID", default=0)
    action_teeth_id = models.IntegerField(db_column="rf_kl_ActionTeethID", default=0)
    usl_profit_type_id = models.IntegerField(db_column="rf_usl_ProfitTypeID", default=0)
    date_warranty = models.DateTimeField(db_column="DateWarranty", default=datetime.date(2222, 1, 1))
    is_fail_warranty = models.BooleanField(db_column="IsFailWarranty", default=0)
    assistant_doc_prvd_id = models.IntegerField(db_column="rf_AssistantDocPRVDID", default=0)
    nom_service_id = models.IntegerField(db_column="rf_kl_NomServiceID", default=0)
    dogovor_paying_id = models.IntegerField(db_column="rf_DogovorPayingID", default=0)

    class Meta:
        managed = False
        db_table = "hlt_SMTAP"



from .base_model import *


class OmsMkb(BaseModel):
    """
    Классификатор болезней МКБ-10
    """

    id = models.AutoField(db_column="MKBID", primary_key=True)
    ds = models.CharField(db_column="DS", max_length=10)
    name = models.CharField(db_column="NAME", max_length=255)
    date_b = models.DateField(db_column="Date_B")
    date_e = models.DateField(db_column="Date_E")
    rem = models.CharField(db_column="Rem", max_length=250)

    flags = models.IntegerField(db_column="Flags")

    class Meta:
        managed = False
        db_table = "oms_MKB"



from .base_model import *


class XUser(BaseModel):
    id = models.AutoField(db_column="UserID", primary_key=True)
    uuid = models.CharField(db_column="GUID", max_length=36, unique=True)
    windows_name = models.CharField(db_column="WindowsName", max_length=500)
    general_login = models.CharField(db_column="GeneralLogin", max_length=50)
    general_password = models.CharField(db_column="GeneralPassword", max_length=50)
    auth_mode = models.SmallIntegerField(db_column="AuthMode")
    fio = models.CharField(db_column="FIO", max_length=50, blank=True, null=True)
    email = models.CharField(db_column="Email", max_length=256)

    class Meta:
        managed = False
        db_table = "x_User"



from .base_model import *


class OmsServiceMedical(BaseModel):
    id = models.AutoField(db_column="ServiceMedicalID", primary_key=True)
    code = models.CharField(db_column="ServiceMedicalCode", max_length=50)
    name = models.CharField(db_column="ServiceMedicalName", max_length=500)
    visit_type_id = models.IntegerField(db_column="rf_kl_VisitTypeID")
    dd_service = models.ForeignKey("OmsKlDDService", db_column="rf_kl_DDServiceID", **FK_DEFAULT)
    med_care_type = models.ForeignKey("OmsKlMedCareType", db_column="rf_kl_MedCareTypeID", **FK_DEFAULT)
    med_care_unit_id = models.IntegerField(db_column="rf_kl_MedCareUnitID")
    operation_type_id = models.IntegerField(db_column="rf_kl_OperationTypeID")
    nom_service_id = models.IntegerField(db_column="rf_kl_NomServiceID")
    age_group = models.ForeignKey("OmsKlAgeGroup", db_column="rf_kl_AgeGroupID", **FK_DEFAULT)
    department_type = models.ForeignKey("OmsKlDepartmentType", db_column="rf_kl_DepartmentTypeID", **FK_DEFAULT)
    department_profile = models.ForeignKey(
        "OmsKlDepartmentProfile", db_column="rf_kl_DepartmentProfileID", **FK_DEFAULT
    )
    uuid = models.CharField(db_column="GUIDSM", max_length=36)
    date_b = models.DateTimeField(db_column="Date_B")
    date_e = models.DateTimeField(db_column="Date_E")
    id_serv = models.CharField(db_column="IDServ", max_length=40)
    prvd = models.ForeignKey("OmsPrvd", db_column="rf_PRVDID", **FK_DEFAULT)
    prvs = models.ForeignKey("OmsPrvs", db_column="rf_PRVSID", **FK_DEFAULT)
    service_medical = models.ForeignKey("OmsServiceMedical", db_column="rf_ServiceMedicalID", **FK_DEFAULT)
    doc = models.CharField(db_column="DOC", max_length=255)
    med_care_licence_id = models.IntegerField(db_column="rf_kl_MedCareLicenceID")
    sex_id = models.IntegerField(db_column="rf_kl_SexID")
    standart_cure_id = models.IntegerField(db_column="rf_sc_StandartCureID")
    fcode_usl = models.CharField(db_column="FCode_Usl", max_length=50)
    info = models.TextField(db_column="Info")
    flags = models.IntegerField(db_column="Flags")
    is_complex = models.BooleanField(db_column="isComplex")
    metod_hmp_id = models.IntegerField(db_column="rf_kl_MetodHMPID")
    action_teeth_id = models.IntegerField(db_column="rf_kl_ActionTeethID")
    profit_type_id = models.IntegerField(db_column="rf_kl_ProfitTypeID")
    is_dental_tech = models.BooleanField(db_column="isDentalTech")
    service_life = models.IntegerField(db_column="ServiceLife")
    warranty = models.IntegerField(db_column="Warranty")

    class Meta:
        managed = False
        db_table = "Oms_ServiceMedical"



from .base_model import *


class AtfFileAttachment(BaseModel):
    id = models.AutoField(db_column="FileAttachmentID", primary_key=True)
    uuid = models.CharField(db_column="Guid", max_length=36, unique=True, default=uuid4)

    num = models.IntegerField(db_column="Num", default=0)
    description = models.TextField(db_column="Description", default="")
    path = models.CharField(db_column="Path", max_length=500)
    date_create = models.DateTimeField(db_column="DateCreate", default=timezone.now)
    create_username = models.CharField(db_column="CreateUserName", max_length=255, default="")
    create_user = models.ForeignKey("XUser", db_column="rf_CreateUserID", **FK_DEFAULT)
    file_info = models.ForeignKey(
        "AtfFileInfo",
        models.DO_NOTHING,
        related_name="attachments",
        db_column="rf_FileInfoID",
    )

    flags = models.IntegerField(db_column="Flags", default=0)

    class Meta:
        managed = False
        db_table = "atf_FileAttachment"



from .base_model import *


class OmsKlStatCureResult(BaseModel):
    id = models.AutoField(db_column="kl_StatCureResultID", primary_key=True)
    guid = models.CharField(db_column="StatCureResultGUID", max_length=36)

    code = models.CharField(db_column="CODE", max_length=50)
    name = models.CharField(db_column="NAME", max_length=255)
    date_b = models.DateTimeField(db_column="Date_B")
    date_e = models.DateTimeField(db_column="Date_E")
    department_type = models.ForeignKey("OmsKlDepartmentType", db_column="rf_kl_DepartmentTypeID", **FK_DEFAULT)
    code_region = models.CharField(db_column="CODE_Region", max_length=50)
    code_federal = models.CharField(db_column="CODE_Federal", max_length=50)

    class Meta:
        managed = False
        db_table = "oms_kl_StatCureResult"



from .base_model import *


class HltDoctorTimeTable(BaseModel):
    id = models.AutoField(db_column="DoctorTimeTableID", primary_key=True)
    begin_time = models.DateTimeField(db_column="Begin_Time")
    end_time = models.DateTimeField(db_column="End_Time")
    date = models.DateTimeField(db_column="Date")
    lpu_doctor = models.ForeignKey("HltLpuDoctor", db_column="rf_LPUDoctorID", **FK_DEFAULT)
    doc_busy_type_id = models.IntegerField(db_column="rf_DocBusyType")
    flag_access = models.IntegerField(db_column="FlagAccess")
    flags = models.IntegerField(db_column="FLAGS")
    uguid = models.CharField(db_column="UGUID", max_length=36)
    last_stub_num = models.IntegerField(db_column="LastStubNum")
    plan_ue = models.IntegerField(db_column="PlanUE")
    doc_prvd = models.ForeignKey("HltDocPrvd", db_column="rf_DocPRVDID", **FK_DEFAULT)
    healing_room_id = models.IntegerField(db_column="rf_HealingRoomID")
    tt_source = models.IntegerField(db_column="TTSource")
    used_ue = models.IntegerField(db_column="UsedUE")
    is_katl_visit = models.BooleanField(db_column="IsKatlVisit")
    is_out_schedule = models.BooleanField(db_column="IsOutSchedule")
    comment_mobil_brigade = models.CharField(db_column="CommentMobilBrigade", max_length=1000)
    address_mobil_brigade_id = models.IntegerField(db_column="rf_AddressMobilBrigadeID")

    class Meta:
        managed = False
        db_table = "hlt_DoctorTimeTable"



from .base_model import *


class KlaStreet(BaseModel):
    id = models.AutoField(db_column="StreetID", primary_key=True)
    socr = models.CharField(db_column="SOCR", max_length=10)
    code = models.CharField(db_column="CODE", max_length=17)
    uno = models.CharField(db_column="UNO", max_length=4)
    ocatd = models.CharField(db_column="OCATD", max_length=11)
    source = models.CharField(db_column="Source", max_length=5)
    alt_code = models.CharField(db_column="AltCode", max_length=50)
    name = models.CharField(db_column="Name", max_length=40)
    gninmb = models.CharField(db_column="GNINMB", max_length=4)
    post_index = models.CharField(db_column="PostIndex", max_length=6)
    kladr = models.ForeignKey("KlaKladr", models.DO_NOTHING, db_column="rf_KlAdrID")
    address_string = models.CharField(db_column="AddressString", max_length=500)

    flags = models.IntegerField(db_column="Flags")

    class Meta:
        managed = False
        db_table = "kla_Street"
